@@ -344,6 +344,19 @@ sub _get_prefix {
     return $mount;
 }
 
+sub _prepare_meta_article {
+    my ($self, $article) = @_;
+    return {
+        page_title   => $article->title,
+        page_excerpt => $article->excerpt,
+        page_image   => $article->image,
+        page_tags    => join(', ', @{$article->tags}),
+        page_author  => $article->author,
+        page_url     => $article->permalink,
+        background_image => $article->background, # if set will use the full screen bg
+    };
+}
+
 sub declare_routes {
     my ($self, $plugin, $config) = @_;
 
@@ -380,28 +393,23 @@ sub declare_routes {
             if (! defined $article) {
                 return $plugin->render_client_error("Article not found : $cat/$slug");
             }
-            # TODO hanlde invalid/missing $article->content as a 404
 
-            return $plugin->dsl->template(
-                'liteblog/single-page',
+            return $plugin->dsl->template('liteblog/single-page', 
                 {
-                    page_title => $article->title,
-                    content    => $article->content, 
-                    page_image => $article->image,
-                    background_image => $article->background,
-                    meta       => [
-                        { 
-                            label => $article->category, 
-                            link => "$prefix/$cat" 
-                        },
-                        { 
-                            label => $article->published_date 
-                        }
+                    %{ $self->_prepare_meta_article($article) },
+                    content => $article->content,
+                    meta => [{ 
+                        label => $article->category, 
+                        link => "$prefix/$cat" 
+                    },{ 
+                        label => $article->published_date 
+                    }
                     ],
                 },
                 {
                     layout => 'liteblog'
-                });
+                }
+            );
         }
     );
 
@@ -492,13 +500,10 @@ Examples:
             return $plugin->dsl->template(
                 'liteblog/single-page',
                 {
-                    page_title => $article->title,
-                    page_image => $article->image,
-                    background_image => $article->background,
+                    %{ $self->_prepare_meta_article($article) },
                     content    => $article->content, 
-                    meta       => [
-                        { 
-                            label => "Last update: ".$article->published_date 
+                    meta       => [ { 
+                        label => $article->published_date 
                         }
                     ],
                 },
